summaryrefslogtreecommitdiff
path: root/ace/Service_Config.cpp
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1997-08-16 15:10:18 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1997-08-16 15:10:18 +0000
commitbbd109640d28074f80c3971b2b6d1883e9c6ddf4 (patch)
treee2850f2f5e3029317dda4233179cf792edeaa1dc /ace/Service_Config.cpp
parent50887b7ab365f7114480839a0210c714c17d4296 (diff)
downloadATCD-bbd109640d28074f80c3971b2b6d1883e9c6ddf4.tar.gz
*** empty log message ***
Diffstat (limited to 'ace/Service_Config.cpp')
-rw-r--r--ace/Service_Config.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/ace/Service_Config.cpp b/ace/Service_Config.cpp
index 7f702ef1d2b..693bf4a9934 100644
--- a/ace/Service_Config.cpp
+++ b/ace/Service_Config.cpp
@@ -343,11 +343,11 @@ ACE_Service_Config::process_directives (void)
ace_yyerrno = 0;
ace_yylineno = 1;
// Use an ACE_Auto_Ptr to make sure that we release this memory
// regardless of how we exit...
ACE_NEW_RETURN (ace_obstack, ACE_Obstack, -1);
- ACE_Auto_Ptr<ACE_Obstack> holder (ace_obstack);
+ auto_ptr<ACE_Obstack> holder (ace_obstack);
ace_yyparse ();
@@ -670,7 +670,7 @@ template class ACE_Unbounded_Set<ACE_Static_Svc_Descriptor *>;
template class ACE_Unbounded_Set_Iterator<ACE_Static_Svc_Descriptor *>;
template class ACE_Malloc<ACE_LOCAL_MEMORY_POOL, ACE_Null_Mutex>;
template class ACE_Allocator_Adapter<ACE_Malloc<ACE_LOCAL_MEMORY_POOL, ACE_Null_Mutex> >;
-template class ACE_Auto_Ptr<ACE_Obstack>;
+template class auto_ptr<ACE_Obstack>;
template class ACE_Auto_Basic_Ptr<ACE_Obstack>;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#pragma instantiate ACE_Node<ACE_Static_Svc_Descriptor *>
@@ -678,7 +678,7 @@ template class ACE_Auto_Basic_Ptr<ACE_Obstack>;
#pragma instantiate ACE_Unbounded_Set_Iterator<ACE_Static_Svc_Descriptor *>
#pragma instantiate ACE_Malloc<ACE_LOCAL_MEMORY_POOL, ACE_Null_Mutex>
#pragma instantiate ACE_Allocator_Adapter<ACE_Malloc<ACE_LOCAL_MEMORY_POOL, ACE_Null_Mutex> >
-#pragma instantiate ACE_Auto_Ptr<ACE_Obstack>
+#pragma instantiate auto_ptr<ACE_Obstack>
#pragma instantiate ACE_Auto_Basic_Ptr<ACE_Obstack>
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
@@ -343,11 +343,11 @@ ACE_Service_Config::process_directives (void)
ace_yyerrno = 0;
ace_yylineno = 1;
- // Use an ACE_Auto_Ptr to make sure that we release this memory
+ // Use an auto_ptr to make sure that we release this memory
// regardless of how we exit...
ACE_NEW_RETURN (ace_obstack, ACE_Obstack, -1);